@@ -1,28 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Petr Šabata <contyk@redhat.com>
-#            Luboš Kocman <lkocman@redhat.com>
-
-
+# SPDX-License-Identifier: MIT
 import copy
 import logging
 import os
@@ -38,6 +15,7 @@ import kobo.rpmlib
 import threading
 import six.moves.xmlrpc_client as xmlrpclib
 import munch
+import locale
 from itertools import chain
 from OpenSSL.SSL import SysCallError
 import textwrap
@@ -51,7 +29,7 @@ from module_build_service.errors import ProgrammingError
 
 from module_build_service.builder.base import GenericBuilder
 from module_build_service.builder.KojiContentGenerator import KojiContentGenerator
-from module_build_service.utils import get_reusable_components, get_reusable_module
+from module_build_service.utils import get_reusable_components, get_reusable_module, set_locale
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -324,7 +302,8 @@ class KojiModuleBuilder(GenericBuilder):
         name = "module-build-macros"
         version = "0.1"
         release = "1"
-        today = datetime.date.today().strftime("%a %b %d %Y")
+        with set_locale(locale.LC_TIME, "en_US.utf8"):
+            today = datetime.date.today().strftime("%a %b %d %Y")
         mmd = module_build.mmd()
 
         # Generate "Conflicts: name = version-release". This is workaround for
@@ -357,6 +336,18 @@ class KojiModuleBuilder(GenericBuilder):
                     )
                 )
 
+        # These are generated from handle_collisions_with_base_module_rpms and are different than
+        # the stream collision modules
+        ursine_rpms = mmd.get_xmd()["mbs"].get("ursine_rpms")
+        if ursine_rpms:
+            log.debug("Adding %d ursine RPM(s) to the conflicts", len(ursine_rpms))
+            filter_conflicts.append(
+                "\n# Filter out base module RPMs that overlap with the RPMs in the buildrequired "
+                "modules"
+            )
+            for ursine_rpm in ursine_rpms:
+                filter_conflicts.append(KojiModuleBuilder.format_conflicts_line(ursine_rpm))
+
         spec_content = textwrap.dedent("""
             %global dist {disttag}
             %global modularitylabel {module_name}:{module_stream}:{module_version}:{module_context}
@@ -599,49 +590,36 @@ class KojiModuleBuilder(GenericBuilder):
         return tagged_nvrs
 
     def buildroot_add_artifacts(self, artifacts, install=False):
-        """
-        :param artifacts - list of artifacts to add to buildroot
-        :param install=False - force install artifact (if it's not dragged in as dependency)
+        """Add list of artifacts to buildroot
+
+        If any artifact is listed as a blocked package, it will be unblocked.
+
+        Module build tag will be applied to artifacts.
 
         This method is safe to call multiple times.
+
+        :param artifacts: list of artifacts to add to buildroot. Each of them
+            is represented by a string NVR.
+        :type artifacts: list[str]
+        :kwarg bool install: force install artifact (if it's not dragged in as
+            dependency). Defaults to False.
+        :raises: error derived from ``koji.GenericError`` if any underlying
+            Koji API fails.
         """
-        log.info("%r adding artifacts %r" % (self, artifacts))
-        build_tag = self._get_tag(self.module_build_tag)["id"]
-
-        xmd = self.mmd.get_xmd()
-        if "blocked_packages" in xmd.get("mbs_options", {}):
-            packages = [kobo.rpmlib.parse_nvr(nvr)["name"] for nvr in artifacts]
-            packages = [
-                package for package in packages
-                if package in xmd["mbs_options"]["blocked_packages"]
-            ]
-            if packages:
-                self._koji_unblock_packages(packages)
-
-        tagged_nvrs = self._get_tagged_nvrs(self.module_build_tag["name"])
-
-        self.koji_session.multicall = True
-        for nvr in artifacts:
-            if nvr in tagged_nvrs:
-                continue
-
-            log.info("%r tagging %r into %r" % (self, nvr, build_tag))
-            self.koji_session.tagBuild(build_tag, nvr)
-
-            if not install:
-                continue
-
-            for group in ("srpm-build", "build"):
-                name = kobo.rpmlib.parse_nvr(nvr)["name"]
-                log.info("%r adding %s to group %s" % (self, name, group))
-                self.koji_session.groupPackageListAdd(build_tag, group, name)
-        self.koji_session.multiCall(strict=True)
+        log.info("%r adding artifacts %r", self, artifacts)
+        self.unblock_artifacts(artifacts)
+        self.tag_artifacts(artifacts, dest_tag=False)
+        if install:
+            self.add_artifacts_to_groups(artifacts)
 
     def tag_artifacts(self, artifacts, dest_tag=True):
-        """ Tag the provided artifacts to the module tag
+        """Tag the provided artifacts to the module tag
+
         :param artifacts: a list of NVRs to tag
-        :kwarg dest_tag: a boolean determining if the destination or build tag should be used
-        :return: None
+        :kwarg bool dest_tag: a boolean determining if the destination or build tag
+            should be used. Default is True to apply the destination tag.
+        :raises: error derived from ``koji.GenericError`` if any tagBuild call
+            fails.
         """
         if dest_tag:
             tag = self._get_tag(self.module_tag)["id"]
@@ -662,7 +640,7 @@ class KojiModuleBuilder(GenericBuilder):
     def untag_artifacts(self, artifacts):
         """ Untag the provided artifacts from the module destination and build tag
         :param artifacts: a list of NVRs to untag
-        :return: None
+        :raises: error derived from ``koji.GenericError`` if any untagBuild call fails.
         """
         build_tag_name = self.tag_name + "-build"
         dest_tag = self._get_tag(self.tag_name, strict=False)
@@ -931,14 +909,14 @@ class KojiModuleBuilder(GenericBuilder):
             if record_exists(parent["id"], inheritance_data):
                 continue
 
-            parent_data = {}
-            parent_data["parent_id"] = parent["id"]
-            parent_data["priority"] = priority
-            parent_data["maxdepth"] = None
-            parent_data["intransitive"] = False
-            parent_data["noconfig"] = False
-            parent_data["pkg_filter"] = ""
-            inheritance_data.append(parent_data)
+            inheritance_data.append({
+                "parent_id": parent["id"],
+                "priority": priority,
+                "maxdepth": None,
+                "intransitive": False,
+                "noconfig": False,
+                "pkg_filter": "",
+            })
             priority += 10
 
         if inheritance_data:
@@ -1069,12 +1047,35 @@ class KojiModuleBuilder(GenericBuilder):
         args = [[self.module_build_tag["name"], package] for package in packages]
         koji_multicall_map(self.koji_session, self.koji_session.packageListBlock, args)
 
-    def _koji_unblock_packages(self, packages):
+    def unblock_artifacts(self, artifacts):
         """
         Unblocks the `packages` for the module_build_tag.
         """
-        log.info("Unblocking packages in tag %s: %r", self.module_build_tag["name"], packages)
-        args = [[self.module_build_tag["name"], package] for package in packages]
+        xmd = self.mmd.get_xmd()
+
+        blocked_packages = xmd.get("mbs_options", {}).get("blocked_packages")
+
+        if blocked_packages is None:
+            log.debug("No blocked_packages is set under xmd/mbs_options. No "
+                      "package will be unblocked.")
+            return
+
+        if not blocked_packages:
+            log.debug("No package is listed in xmd/mbs_options/blocked_packages."
+                      " No package will be unblocked.")
+            return
+
+        packages = (kobo.rpmlib.parse_nvr(nvr)["name"] for nvr in artifacts)
+        packages = [package for package in packages if package in blocked_packages]
+
+        if not packages:
+            log.debug("None of %r is listed in xmd/mbs_options/blocked_packages."
+                      " No one will be unblocked.")
+            return
+
+        build_tag_name = self.module_build_tag["name"]
+        log.info("Unblocking packages in tag %s: %r", build_tag_name, packages)
+        args = [[build_tag_name, package] for package in packages]
         koji_multicall_map(self.koji_session, self.koji_session.packageListUnblock, args)
 
     @module_build_service.utils.validate_koji_tag(["build_tag", "dest_tag"])
@@ -1344,3 +1345,23 @@ class KojiModuleBuilder(GenericBuilder):
         if not tag["arches"]:
             return []
         return tag["arches"].split(" ")
+
+    def add_artifacts_to_groups(self, artifacts, groups=None):
+        """Add artifacts to groups
+
+        :param artifacts: list of NVRs to add to groups.
+        :type artifacts: list[str]
+        :param groups: list of groups to contain specified artifacts. Defaults
+            to srpm-build and build.
+        :type groups: list[str]
+        :raises: error derived from ``koji.GenericError`` if any
+            groupPackageListAdd call fails.
+        """
+        build_tag = self._get_tag(self.module_build_tag)["id"]
+        self.koji_session.multicall = True
+        for nvr in artifacts:
+            for group in groups or ("srpm-build", "build"):
+                name = kobo.rpmlib.parse_nvr(nvr)["name"]
+                log.info("%r adding %s to group %s", self, name, group)
+                self.koji_session.groupPackageListAdd(build_tag, group, name)
+        self.koji_session.multiCall(strict=True)
