@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 import os
 import shutil
 import subprocess
@@ -39,7 +41,7 @@ def execute_cmd(args, stdout=None, stderr=None, cwd=None):
     if stderr and hasattr(stderr, "name"):
         out_log_msg += ", stderr log: %s" % stderr.name
 
-    log.info("Executing command: %s%s" % (args, out_log_msg))
+    log.info("Executing the command \"%s\"%s" % (" ".join(args), out_log_msg))
     proc = subprocess.Popen(args, stdout=stdout, stderr=stderr, cwd=cwd)
     out, err = proc.communicate()
 
