@@ -1,29 +1,5 @@
 # -*- coding: utf-8 -*-
-
-
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Petr Šabata <contyk@redhat.com>
-#            Filip Valder <fvalder@redhat.com>
-
+# SPDX-License-Identifier: MIT
 import imp
 import os
 import pkg_resources
@@ -254,7 +230,7 @@ class Config(object):
         },
         "allowed_groups": {
             "type": set,
-            "default": set(["packager"]),
+            "default": {"packager"},
             "desc": "The set of groups allowed to submit builds.",
         },
         "allowed_groups_to_import_module": {
@@ -383,7 +359,7 @@ class Config(object):
         "no_auth": {"type": bool, "default": False, "desc": "Disable client authentication."},
         "admin_groups": {
             "type": set,
-            "default": set([]),
+            "default": set(),
             "desc": "The set of groups allowed to manage MBS.",
         },
         "yum_config_file": {
@@ -640,6 +616,12 @@ class Config(object):
             "default": False,
             "desc": "Allow module scratch builds",
         },
+        "scratch_build_only_branches": {
+            "type": list,
+            "default": [],
+            "desc": "The list of regexes used to identify branches from which only the module "
+                    "scratch builds can be built",
+        },
         "product_pages_url": {
             "type": str,
             "default": "",
@@ -665,6 +647,31 @@ class Config(object):
             "desc": "The number of threads when submitting component builds to an external build "
                     "system.",
         },
+        "default_modules_scm_url": {
+            "type": str,
+            "default": "https://pagure.io/releng/fedora-module-defaults.git",
+            "desc": "The SCM URL to the default modules repo, which will be used to determine "
+                    "which buildrequires to automatically include. This can be overridden with "
+                    "the xmd.mbs.default_modules_scm_url key in the base module's modulemd.",
+        },
+        "uses_rawhide": {
+            "type": bool,
+            "default": True,
+            "desc": "Denotes if the concept of rawhide exists in the infrastructure of this "
+                    "MBS deployment.",
+        },
+        "rawhide_branch": {
+            "type": str,
+            "default": "master",
+            "desc": "Denotes the branch used for rawhide.",
+        },
+        "dnf_minrate": {
+            "type": int,
+            "default": 1024 * 100,  # 100KB
+            "desc": "The minrate configuration on a DNF repo. This configuration will cause DNF to "
+                    "timeout loading a repo if the download speed is below minrate for the "
+                    "duration of the timeout."
+        }
     }
 
     def __init__(self, conf_section_obj):
