@@ -1,34 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Petr Šabata <contyk@redhat.com>
-#            Ralph Bean <rbean@redhat.com>
-#            Matt Prahl <mprahl@redhat.com>
-
+# SPDX-License-Identifier: MIT
 """ SQLAlchemy Database models for the Flask app
 """
 
 import contextlib
 import hashlib
 import json
+import koji
 import re
 from collections import OrderedDict, namedtuple
 from datetime import datetime
@@ -85,7 +63,8 @@ INVERSE_BUILD_STATES = {v: k for k, v in BUILD_STATES.items()}
 FAILED_STATES = (BUILD_STATES["failed"], BUILD_STATES["garbage"])
 
 
-Contexts = namedtuple("Contexts", "build_context runtime_context context")
+Contexts = namedtuple(
+    "Contexts", "build_context runtime_context context build_context_no_bms")
 
 
 def _utc_datetime_to_iso(datetime_object):
@@ -256,6 +235,7 @@ class ModuleBuild(MBSBase):
     stream = db.Column(db.String, nullable=False)
     version = db.Column(db.String, nullable=False)
     build_context = db.Column(db.String)
+    build_context_no_bms = db.Column(db.String)
     runtime_context = db.Column(db.String)
     context = db.Column(db.String, nullable=False, server_default=DEFAULT_MODULE_CONTEXT)
     state = db.Column(db.Integer, nullable=False)
@@ -438,7 +418,8 @@ class ModuleBuild(MBSBase):
             allowing to set additional filter for results.
         """
         return ModuleBuild._get_last_builds_in_stream_query(
-            db_session, name, stream, **kwargs).first()
+            db_session, name, stream, **kwargs
+        ).first()
 
     @staticmethod
     def get_build_from_nsvc(db_session, name, stream, version, context, **kwargs):
@@ -645,24 +626,30 @@ class ModuleBuild(MBSBase):
         mmd_deps = mmd.get_dependencies()
 
         build_context = cls.calculate_build_context(mbs_xmd_buildrequires)
+        build_context_no_bms = cls.calculate_build_context(mbs_xmd_buildrequires, True)
         runtime_context = cls.calculate_runtime_context(mmd_deps)
 
         return Contexts(
             build_context,
             runtime_context,
-            cls.calculate_module_context(build_context, runtime_context)
+            cls.calculate_module_context(build_context, runtime_context),
+            build_context_no_bms
         )
 
     @staticmethod
-    def calculate_build_context(mbs_xmd_buildrequires):
+    def calculate_build_context(mbs_xmd_buildrequires, filter_base_modules=False):
         """
         Returns the hash of stream names of expanded buildrequires
         :param mbs_xmd_buildrequires: xmd["mbs"]["buildrequires"] from Modulemd
+        :param bool filter_base_modules: When True, base modules are not used to compute
+            the build context.
         :rtype: str
         :return: build_context hash
         """
+        deps_to_filter = conf.base_module_names if filter_base_modules else []
         mmd_formatted_buildrequires = {
             dep: info["stream"] for dep, info in mbs_xmd_buildrequires.items()
+            if dep not in deps_to_filter
         }
         property_json = json.dumps(OrderedDict(sorted(mmd_formatted_buildrequires.items())))
         return hashlib.sha1(property_json.encode("utf-8")).hexdigest()
@@ -1232,6 +1219,8 @@ class ComponentBuild(MBSBase):
     # True when this component build is build-time only (should be tagged only
     # to -build tag)
     build_time_only = db.Column(db.Boolean, default=False)
+    # True if buildonly is True in modulemd
+    buildonly = db.Column(db.Boolean, default=False)
 
     # A monotonically increasing integer that represents which batch or
     # iteration this *component* is currently in.  This relates to the owning
@@ -1350,6 +1339,37 @@ class ComponentBuild(MBSBase):
             self.state_reason,
         )
 
+    @property
+    def is_completed(self):
+        return self.state == koji.BUILD_STATES["COMPLETE"]
+
+    @property
+    def is_building(self):
+        return self.state == koji.BUILD_STATES["BUILDING"]
+
+    @property
+    def is_failed(self):
+        return self.state == koji.BUILD_STATES["FAILED"]
+
+    @property
+    def is_waiting_for_build(self):
+        return self.state is None
+
+    @property
+    def is_unbuilt(self):
+        return self.is_waiting_for_build or self.is_building
+
+    @property
+    def is_tagged(self):
+        return self.tagged and (self.tagged_in_final or self.build_time_only)
+
+    @property
+    def is_unsuccessful(self):
+        return (
+            self.state == koji.BUILD_STATES["FAILED"]
+            or self.state == koji.BUILD_STATES["CANCELED"]
+        )
+
 
 class ComponentBuildTrace(MBSBase):
     __tablename__ = "component_builds_trace"
