@@ -1,27 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Matt Prahl <mprahl@redhat.com>
-#            Jan Kaluza <jkaluza@redhat.com>
-
+# SPDX-License-Identifier: MIT
 from sqlalchemy.orm import aliased
 
 from module_build_service import log, db
@@ -155,19 +133,19 @@ class DBResolver(GenericResolver):
 
         return [build.mmd() for build in builds]
 
-    def get_buildrequired_modulemds(self, name, stream, base_module_nsvc):
+    def get_buildrequired_modulemds(self, name, stream, base_module_mmd):
         """
         Returns modulemd metadata of all module builds with `name` and `stream` buildrequiring
-        base module defined by `base_module_nsvc` NSVC.
+        base module defined by `base_module_mmd` NSVC.
 
         :param str name: Name of module to return.
         :param str stream: Stream of module to return.
-        :param str base_module_nsvc: NSVC of base module which must be buildrequired by returned
+        :param Modulemd base_module_mmd: NSVC of base module which must be buildrequired by returned
             modules.
         :rtype: list
         :return: List of modulemd metadata.
         """
-        log.debug("Looking for %s:%s buildrequiring %s", name, stream, base_module_nsvc)
+        log.debug("Looking for %s:%s buildrequiring %s", name, stream, base_module_mmd.get_nsvc())
         query = self.db_session.query(models.ModuleBuild)
         query = query.filter_by(name=name, stream=stream, state=models.BUILD_STATES["ready"])
 
@@ -182,8 +160,8 @@ class DBResolver(GenericResolver):
         query = query.join(mb_to_br, mb_to_br.c.module_id == models.ModuleBuild.id).join(
             module_br_alias, mb_to_br.c.module_buildrequire_id == module_br_alias.id)
 
-        # Get only modules buildrequiring particular base_module_nsvc
-        n, s, v, c = base_module_nsvc.split(":")
+        # Get only modules buildrequiring particular base_module_mmd
+        n, s, v, c = base_module_mmd.get_nsvc().split(":")
         query = query.filter(
             module_br_alias.name == n,
             module_br_alias.stream == s,
@@ -388,14 +366,26 @@ class DBResolver(GenericResolver):
 
             if module_version is None or module_context is None:
                 build = models.ModuleBuild.get_last_build_in_stream(
-                    self.db_session, module_name, module_stream)
+                    self.db_session, module_name, module_stream
+                )
             else:
                 build = models.ModuleBuild.get_build_from_nsvc(
-                    self.db_session, module_name, module_stream, module_version, module_context)
+                    self.db_session, module_name, module_stream, module_version, module_context
+                )
 
             if not build:
                 raise UnprocessableEntity("The module {} was not found".format(nsvc))
 
+            for sibling_id in build.siblings(self.db_session):
+                sibling_build = models.ModuleBuild.get_by_id(self.db_session, sibling_id)
+                if sibling_build.state not in (
+                        models.BUILD_STATES["ready"], models.BUILD_STATES["failed"]
+                ):
+                    raise UnprocessableEntity('Buildrequire {}-{}-{} is in "{}" state'.format(
+                        sibling_build.name, sibling_build.stream, sibling_build.version,
+                        models.INVERSE_BUILD_STATES[sibling_build.state]
+                    ))
+
             commit_hash = None
             mmd = build.mmd()
             mbs_xmd = mmd.get_xmd().get("mbs", {})
