@@ -1,28 +1,5 @@
 # -*- coding: utf-8 -*-
-
-
-# Copyright (c) 2018  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Martin Curlej <mcurlej@redhat.com>
-
+# SPDX-License-Identifier: MIT
 """MBS handler functions."""
 
 import logging
@@ -269,6 +246,12 @@ class MBSResolver(GenericResolver):
         :rtype: list
         :return: List of modulemd metadata.
         """
+        # If user used --add-local-build, we do actually not care about base_module_nsvc,
+        # because the user directly asked us to use that module.
+        local_modules = models.ModuleBuild.local_modules(self.db_session, name, stream)
+        if local_modules:
+            return [m.mmd() for m in local_modules]
+
         modules = self._get_modules(name, stream, strict=False, base_module_br=base_module_nsvc)
         return [load_mmd(module["modulemd"]) for module in modules]
 
