@@ -1,26 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Ralph Bean <rbean@redhat.com>
-
+# SPDX-License-Identifier: MIT
 """ Handlers for module change events on the message bus. """
 
 from module_build_service import conf, models, log, build_logs
@@ -38,7 +17,8 @@ from module_build_service.utils import (
 )
 from module_build_service.errors import UnprocessableEntity, Forbidden, ValidationError
 from module_build_service.utils.greenwave import greenwave
-from module_build_service.scheduler.default_modules import add_default_modules
+from module_build_service.scheduler.default_modules import (
+    add_default_modules, handle_collisions_with_base_module_rpms)
 from module_build_service.utils.submit import format_mmd
 from module_build_service.utils.ursine import handle_stream_collision_modules
 
@@ -77,11 +57,6 @@ def failed(config, db_session, msg):
         # This is ok.. it's a race condition we can ignore.
         pass
 
-    unbuilt_components = [
-        c for c in build.component_builds
-        if (c.state != koji.BUILD_STATES["COMPLETE"] and c.state != koji.BUILD_STATES["FAILED"])
-    ]
-
     if build.koji_tag:
         builder = module_build_service.builder.GenericBuilder.create_from_module(
             db_session, build, config)
@@ -89,7 +64,7 @@ def failed(config, db_session, msg):
         if build.new_repo_task_id:
             builder.cancel_build(build.new_repo_task_id)
 
-        for component in unbuilt_components:
+        for component in (c for c in build.component_builds if c.is_unbuilt):
             if component.task_id:
                 builder.cancel_build(component.task_id)
             component.state = koji.BUILD_STATES["FAILED"]
@@ -160,6 +135,15 @@ def init(config, db_session, msg):
             break
         time.sleep(1)
 
+    # for MockModuleBuilder, set build logs dir to mock results dir
+    # before build_logs start
+    if conf.system == "mock":
+        build_tag_name = generate_module_build_koji_tag(build)
+        mock_resultsdir = os.path.join(conf.mock_resultsdir, build_tag_name)
+        if not os.path.exists(mock_resultsdir):
+            os.makedirs(mock_resultsdir)
+        build_logs.build_logs_dir = mock_resultsdir
+
     build_logs.start(db_session, build)
     log.info("Start to handle %s which is in init state.", build.mmd().get_nsvc())
 
@@ -167,9 +151,9 @@ def init(config, db_session, msg):
     failure_reason = "unspec"
     try:
         mmd = build.mmd()
-        arches = [arch.name for arch in build.arches]
-        add_default_modules(db_session, mmd, arches)
         record_module_build_arches(mmd, build, db_session)
+        arches = [arch.name for arch in build.arches]
+        defaults_added = add_default_modules(db_session, mmd, arches)
 
         # Format the modulemd by putting in defaults and replacing streams that
         # are branches with commit hashes
@@ -177,9 +161,24 @@ def init(config, db_session, msg):
         record_component_builds(db_session, mmd, build)
 
         # The ursine.handle_stream_collision_modules is Koji specific.
-        if conf.system in ["koji", "test"]:
+        # It is also run only when Ursa Prime is not enabled for the base
+        # module (`if not defaults_added`).
+        if conf.system in ["koji", "test"] and not defaults_added:
             handle_stream_collision_modules(db_session, mmd)
 
+        # Sets xmd["mbs"]["ursine_rpms"] with RPMs from the buildrequired base modules which
+        # conflict with the RPMs from other buildrequired modules. This is done to prefer modular
+        # RPMs over base module RPMs even if their NVR is lower.
+        if conf.system in ("koji", "test"):
+            handle_collisions_with_base_module_rpms(mmd, arches)
+        else:
+            log.warning(
+                "The necessary conflicts could not be generated due to RHBZ#1693683. "
+                "Some RPMs from the base modules (%s) may end up being used over modular RPMs. "
+                "This may result in different behavior than a production build.",
+                ", ".join(conf.base_module_names)
+            )
+
         mmd = record_filtered_rpms(db_session, mmd)
         build.modulemd = mmd_to_str(mmd)
         build.transition(db_session, conf, models.BUILD_STATES["wait"])
@@ -425,7 +424,7 @@ def wait(config, db_session, msg):
             component_build.state = state
             component_build.reason = reason
             component_build.nvr = nvr
-    elif component_build.state != koji.BUILD_STATES["COMPLETE"]:
+    elif not component_build.is_completed:
         # It's possible that the build succeeded in the builder but some other step failed which
         # caused module-build-macros to be marked as failed in MBS, so check to see if it exists
         # first
