@@ -1,25 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-
+# SPDX-License-Identifier: MIT
 """ The PollingProducer class that acts as a producer entry point for
 fedmsg-hub. This class polls the database for tasks to do.
 """
@@ -163,10 +143,7 @@ class MBSProducer(PollingProducer):
             for module in stale_module_builds:
                 log.info("{0!r} is stale and is being cleaned up".format(module))
                 # Find completed artifacts in the stale build
-                artifacts = [
-                    c for c in module.component_builds
-                    if c.state == koji.BUILD_STATES["COMPLETE"]
-                ]
+                artifacts = [c for c in module.component_builds if c.is_completed]
                 # If there are no completed artifacts, then there is nothing to tag
                 if artifacts:
                     # Set buildroot_connect=False so it doesn't recreate the Koji target and etc.
@@ -482,7 +459,7 @@ class MBSProducer(PollingProducer):
 
         module_builds = (
             db_session.query(models.ModuleBuild)
-            .filter_by(state=models.BUILD_STATES["done"]).all()
+            .filter_by(state=models.BUILD_STATES["done"], scratch=False).all()
         )
 
         log.info("Checking Greenwave for %d builds", len(module_builds))
