@@ -1,32 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Ralph Bean <rbean@redhat.com>
-#            Matt Prahl <mprahl@redhat.com>
-#            Jan Kaluza <jkaluza@redhat.com>
+# SPDX-License-Identifier: MIT
 import os
 import functools
 import inspect
 import hashlib
 import time
+import locale
+import contextlib
 from datetime import datetime
 from functools import partial
 
@@ -525,9 +505,10 @@ def import_mmd(db_session, mmd, check_buildrequires=True):
     build.context = context
     build.owner = "mbs_import"
     build.rebuild_strategy = "all"
-    build.time_submitted = datetime.utcnow()
-    build.time_modified = datetime.utcnow()
-    build.time_completed = datetime.utcnow()
+    now = datetime.utcnow()
+    build.time_submitted = now
+    build.time_modified = now
+    build.time_completed = now
     if build.name in conf.base_module_names:
         build.stream_version = models.ModuleBuild.get_stream_version(stream)
 
@@ -760,3 +741,10 @@ def mmd_to_str(mmd):
     index = Modulemd.ModuleIndex()
     index.add_module_stream(mmd)
     return to_text_type(index.dump_to_string())
+
+
+@contextlib.contextmanager
+def set_locale(*args, **kwargs):
+    saved = locale.setlocale(locale.LC_ALL)
+    yield locale.setlocale(*args, **kwargs)
+    locale.setlocale(locale.LC_ALL, saved)
