@@ -1,27 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Ralph Bean <rbean@redhat.com>
-#            Matt Prahl <mprahl@redhat.com>
-#            Jan Kaluza <jkaluza@redhat.com>
+# SPDX-License-Identifier: MIT
 from module_build_service import log, models, Modulemd, conf
 from module_build_service.errors import StreamAmbigous
 from module_build_service.errors import UnprocessableEntity
@@ -105,7 +83,7 @@ def expand_mse_streams(db_session, mmd, default_streams=None, raise_if_stream_am
             new_streams = _expand_mse_streams(
                 db_session, name, streams, default_streams, raise_if_stream_ambigous)
 
-            if new_streams == []:
+            if not new_streams:
                 new_deps.set_empty_runtime_dependencies_for_module(name)
             else:
                 for stream in new_streams:
@@ -116,7 +94,7 @@ def expand_mse_streams(db_session, mmd, default_streams=None, raise_if_stream_am
             new_streams = _expand_mse_streams(
                 db_session, name, streams, default_streams, raise_if_stream_ambigous)
 
-            if new_streams == []:
+            if not new_streams:
                 new_deps.set_empty_buildtime_dependencies_for_module(name)
             else:
                 for stream in new_streams:
@@ -189,8 +167,7 @@ def _get_mmds_from_requires(
 
             if base_module_mmds:
                 for base_module_mmd in base_module_mmds:
-                    base_module_nsvc = base_module_mmd.get_nsvc()
-                    mmds[ns] += resolver.get_buildrequired_modulemds(name, stream, base_module_nsvc)
+                    mmds[ns] += resolver.get_buildrequired_modulemds(name, stream, base_module_mmd)
             else:
                 mmds[ns] = resolver.get_module_modulemds(name, stream, strict=True)
             added_mmds[ns] += mmds[ns]
@@ -252,6 +229,10 @@ def get_base_module_mmds(db_session, mmd):
                     continue
                 stream_mmd = mmds[0]
 
+                # Add the module to `seen` and `ret`.
+                seen.add(ns)
+                ret["ready"].append(stream_mmd)
+
                 # Get the list of compatible virtual streams.
                 xmd = stream_mmd.get_xmd()
                 virtual_streams = xmd.get("mbs", {}).get("virtual_streams")
@@ -260,8 +241,6 @@ def get_base_module_mmds(db_session, mmd):
                 # it is clear that there are no compatible streams, so return just this
                 # `stream_mmd`.
                 if not virtual_streams:
-                    seen.add(ns)
-                    ret["ready"].append(stream_mmd)
                     continue
 
                 virtual_streams = xmd["mbs"]["virtual_streams"]
@@ -471,7 +450,7 @@ def generate_expanded_mmds(db_session, mmd, raise_if_stream_ambigous=False, defa
             if req_name not in deps_buildrequires:
                 # This require is not a buildrequire so just copy this runtime requirement to
                 # new_dep and don't touch buildrequires
-                if req_streams == []:
+                if not req_streams:
                     new_deps.set_empty_runtime_dependencies_for_module(req_name)
                 else:
                     for req_stream in req_streams:
@@ -479,7 +458,7 @@ def generate_expanded_mmds(db_session, mmd, raise_if_stream_ambigous=False, defa
             elif set(req_streams) != set(deps_buildrequires[req_name]):
                 # Streams in runtime section are not the same as in buildtime section,
                 # so just copy this runtime requirement to new_dep.
-                if req_streams == []:
+                if not req_streams:
                     new_deps.set_empty_runtime_dependencies_for_module(req_name)
                 else:
                     for req_stream in req_streams:
