@@ -1,27 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2018  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Ralph Bean <rbean@redhat.com>
-#            Matt Prahl <mprahl@redhat.com>
-#            Jan Kaluza <jkaluza@redhat.com>
+# SPDX-License-Identifier: MIT
 import json
 import math
 import re
@@ -197,8 +175,6 @@ def format_mmd(mmd, scmurl, module=None, db_session=None):
                     "Custom component caches aren't allowed.  "
                     "%r bears cache %r" % (pkgname, pkg.get_cache())
                 )
-            if pkg.get_buildonly() is True:
-                raise ValidationError('The usage of "buildonly" is not yet supported')
             if pkg.get_buildafter():
                 raise ValidationError('The usage of "buildafter" is not yet supported')
             if not pkg.get_repository():
@@ -530,6 +506,7 @@ def record_component_builds(
             batch=batch,
             ref=component_ref,
             weight=rpm_weights[package],
+            buildonly=component.get_buildonly()
         )
         db_session.add(build)
 
@@ -662,7 +639,7 @@ def _apply_dep_overrides(mmd, params):
                 else:
                     streams_to_add = reqs[name]
 
-                if streams_to_add == []:
+                if not streams_to_add:
                     add_empty_func(name)
                 else:
                     for stream in streams_to_add:
@@ -705,7 +682,7 @@ def _modify_buildtime_streams(db_session, mmd, new_streams_func):
             if streams != new_streams:
                 overridden = True
 
-            if new_streams == []:
+            if not new_streams:
                 new_dep.set_empty_buildtime_dependencies_for_module(name)
             else:
                 for stream in new_streams:
@@ -715,7 +692,7 @@ def _modify_buildtime_streams(db_session, mmd, new_streams_func):
             # Copy the runtime streams as is
             reqs = deps_to_dict(dep, "runtime")
             for name, streams in reqs.items():
-                if streams == []:
+                if not streams:
                     new_dep.set_empty_runtime_dependencies_for_module(name)
                 else:
                     for stream in streams:
@@ -880,7 +857,7 @@ def _process_support_streams(db_session, mmd, params):
                 log.debug("A release date for the release %s could not be determined", pp_release)
                 continue
 
-            if datetime.strptime(ga_date, '%Y-%m-%d') > datetime.utcnow():
+            if datetime.strptime(ga_date, "%Y-%m-%d").date() >= datetime.utcnow().date():
                 log.debug(
                     "The release %s hasn't been released yet. Not adding a stream suffix.",
                     ga_date
@@ -910,7 +887,6 @@ def submit_module_build(db_session, username, mmd, params):
     :rtype: list with ModuleBuild
     :return: List with submitted module builds.
     """
-    import koji  # Placed here to avoid py2/py3 conflicts...
     from .mse import generate_expanded_mmds
 
     log.debug(
@@ -975,7 +951,7 @@ def submit_module_build(db_session, username, mmd, params):
             log.debug("Resuming existing module build %r" % module)
             # Reset all component builds that didn't complete
             for component in module.component_builds:
-                if component.state and component.state != koji.BUILD_STATES["COMPLETE"]:
+                if not component.is_waiting_for_build and not component.is_completed:
                     component.state = None
                     component.state_reason = None
                     db_session.add(component)
@@ -1003,6 +979,18 @@ def submit_module_build(db_session, username, mmd, params):
                 # append incrementing counter to context
                 context_suffix = "_" + str(len(scrmods) + 1)
                 mmd.set_context(mmd.get_context() + context_suffix)
+            else:
+                # In case the branch is defined, check whether user is allowed to submit
+                # non-scratch build from this branch. Note that the branch is always defined
+                # for official builds from SCM, because it is requested in views.py.
+                branch = params.get("branch")
+                if branch:
+                    for regex in conf.scratch_build_only_branches:
+                        branch_search = re.search(regex, branch)
+                        if branch_search:
+                            raise ValidationError(
+                                "Only scratch module builds can be built from this branch."
+                            )
 
             log.debug("Creating new module build")
             module = models.ModuleBuild.create(
@@ -1019,8 +1007,8 @@ def submit_module_build(db_session, username, mmd, params):
                 scratch=params.get("scratch"),
                 srpms=params.get("srpms"),
             )
-            module.build_context, module.runtime_context, module.context = \
-                module.contexts_from_mmd(module.modulemd)
+            module.build_context, module.runtime_context, module.context, \
+                module.build_context_no_bms = module.contexts_from_mmd(module.modulemd)
             module.context += context_suffix
 
         all_modules_skipped = False
