@@ -1,27 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Petr Šabata <contyk@redhat.com>
-#            Matt Prahl <mprahl@redhat.com>
-
+# SPDX-License-Identifier: MIT
 """ The module build orchestrator for Modularity, API.
 This is the implementation of the orchestrator's public RESTful API.
 """
@@ -340,7 +318,7 @@ class LogMessageAPI(MethodView):
 
 
 class BaseHandler(object):
-    valid_params = set([
+    valid_params = {
         "branch",
         "buildrequire_overrides",
         "modulemd",
@@ -352,7 +330,7 @@ class BaseHandler(object):
         "scmurl",
         "scratch",
         "srpms",
-    ])
+    }
 
     def __init__(self, request, data=None):
         self.username, self.groups = module_build_service.auth.get_user(request)
