@@ -1,28 +1,9 @@
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Ralph Bean <rbean@redhat.com>
-# Written by Matt Prahl <mprahl@redhat.com>
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 from os import path, environ
 
 import pytest
+import requests
 import mock
 from mock import patch, PropertyMock, Mock
 import kerberos
@@ -65,7 +46,7 @@ class TestAuthModule:
             mocked_get_token_info = {
                 "active": False,
                 "username": name,
-                "scope": ("openid https://id.fedoraproject.org/scope/groups mbs-scope"),
+                "scope": "openid https://id.fedoraproject.org/scope/groups mbs-scope"
             }
             get_token_info.return_value = mocked_get_token_info
 
@@ -83,7 +64,39 @@ class TestAuthModule:
                     module_build_service.auth.get_user(request)
                 assert str(cm.value) == "OIDC token invalid or expired."
 
-    @pytest.mark.parametrize("allowed_users", (set(), set(["Joey Jo Jo Junior Shabadoo"])))
+    @patch("module_build_service.auth._get_token_info")
+    @patch("module_build_service.auth._get_user_info")
+    def test_get_user_not_in_groups(self, get_user_info, get_token_info):
+        base_dir = path.abspath(path.dirname(__file__))
+        client_secrets = path.join(base_dir, "client_secrets.json")
+        with patch.dict(
+            "module_build_service.app.config",
+            {"OIDC_CLIENT_SECRETS": client_secrets, "OIDC_REQUIRED_SCOPE": "mbs-scope"},
+        ):
+            # https://www.youtube.com/watch?v=G-LtddOgUCE
+            name = "Joey Jo Jo Junior Shabadoo"
+            mocked_get_token_info = {
+                "active": True,
+                "username": name,
+                "scope": "openid https://id.fedoraproject.org/scope/groups mbs-scope"
+            }
+            get_token_info.return_value = mocked_get_token_info
+
+            get_user_info.side_effect = requests.Timeout("It happens...")
+
+            headers = {"authorization": "Bearer foobar"}
+            request = mock.MagicMock()
+            request.headers.return_value = mock.MagicMock(spec_set=dict)
+            request.headers.__getitem__.side_effect = headers.__getitem__
+            request.headers.__setitem__.side_effect = headers.__setitem__
+            request.headers.__contains__.side_effect = headers.__contains__
+
+            with pytest.raises(module_build_service.errors.Unauthorized) as cm:
+                with app.app_context():
+                    module_build_service.auth.get_user(request)
+                assert str(cm.value) == "OpenIDC auth error: Cannot determine the user's groups"
+
+    @pytest.mark.parametrize("allowed_users", (set(), {"Joey Jo Jo Junior Shabadoo"}))
     @patch.object(mbs_config.Config, "allowed_users", new_callable=PropertyMock)
     @patch("module_build_service.auth._get_token_info")
     @patch("module_build_service.auth._get_user_info")
@@ -261,7 +274,7 @@ class KerberosMockConfig(object):
 
 
 class TestAuthModuleKerberos:
-    @pytest.mark.parametrize("allowed_users", (set(), set(["mprahl"])))
+    @pytest.mark.parametrize("allowed_users", (set(), {"mprahl"}))
     @patch("kerberos.authGSSServerInit", return_value=(kerberos.AUTH_GSS_COMPLETE, object()))
     @patch("kerberos.authGSSServerStep", return_value=kerberos.AUTH_GSS_COMPLETE)
     @patch("kerberos.authGSSServerResponse", return_value="STOKEN")
