@@ -1,25 +1,5 @@
-# Copyright (c) 2016  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-# Written by Jan Kaluza <jkaluza@redhat.com>
-
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 import koji
 import os
 import re
@@ -38,7 +18,7 @@ from module_build_service.errors import Forbidden
 from module_build_service import models, conf, build_logs
 from module_build_service.scheduler import make_simple_stop_condition
 
-from mock import patch, PropertyMock, Mock
+from mock import patch, PropertyMock, Mock, MagicMock
 from werkzeug.datastructures import FileStorage
 import kobo
 import pytest
@@ -55,7 +35,7 @@ from tests import (
 
 base_dir = dirname(dirname(__file__))
 
-user = ("Homer J. Simpson", set(["packager"]))
+user = ("Homer J. Simpson", {"packager"})
 
 
 class FakeSCM(object):
@@ -145,7 +125,7 @@ class FakeModuleBuilder(GenericBuilder):
 
     def buildroot_connect(self, groups):
         default_groups = FakeModuleBuilder.DEFAULT_GROUPS or {
-            "srpm-build": set([
+            "srpm-build": {
                 "shadow-utils",
                 "fedora-release",
                 "redhat-rpm-config",
@@ -153,8 +133,8 @@ class FakeModuleBuilder(GenericBuilder):
                 "fedpkg-minimal",
                 "gnupg2",
                 "bash",
-            ]),
-            "build": set([
+            },
+            "build": {
                 "unzip",
                 "fedora-release",
                 "tar",
@@ -179,7 +159,7 @@ class FakeModuleBuilder(GenericBuilder):
                 "rpm-build",
                 "gzip",
                 "gcc-c++",
-            ]),
+            },
         }
         if groups != default_groups:
             raise ValueError("Wrong groups in FakeModuleBuilder.buildroot_connect()")
@@ -371,7 +351,7 @@ class BaseTestBuild:
 @patch(
     "module_build_service.builder.GenericBuilder.default_buildroot_groups",
     return_value={
-        "srpm-build": set([
+        "srpm-build": {
             "shadow-utils",
             "fedora-release",
             "redhat-rpm-config",
@@ -379,8 +359,8 @@ class BaseTestBuild:
             "fedpkg-minimal",
             "gnupg2",
             "bash",
-        ]),
-        "build": set([
+        },
+        "build": {
             "unzip",
             "fedora-release",
             "tar",
@@ -405,7 +385,7 @@ class BaseTestBuild:
             "rpm-build",
             "gzip",
             "gcc-c++",
-        ]),
+        },
     },
 )
 class TestBuild(BaseTestBuild):
@@ -468,8 +448,8 @@ class TestBuild(BaseTestBuild):
 
         # Check that components are tagged after the batch is built.
         tag_groups = [
-            set(["perl-Tangerine-1-1", "perl-List-Compare-1-1"]),
-            set(["tangerine-1-1"]),
+            {"perl-Tangerine-1-1", "perl-List-Compare-1-1"},
+            {"tangerine-1-1"},
         ]
 
         def on_finalize_cb(cls, succeeded):
@@ -484,9 +464,9 @@ class TestBuild(BaseTestBuild):
         # Check that the components are added to buildroot after the batch
         # is built.
         buildroot_groups = [
-            set(["module-build-macros-1-1"]),
-            set(["perl-Tangerine-1-1", "perl-List-Compare-1-1"]),
-            set(["tangerine-1-1"]),
+            {"module-build-macros-1-1"},
+            {"perl-Tangerine-1-1", "perl-List-Compare-1-1"},
+            {"tangerine-1-1"},
         ]
 
         def on_buildroot_add_artifacts_cb(cls, artifacts, install):
@@ -517,6 +497,74 @@ class TestBuild(BaseTestBuild):
         assert module_build.module_builds_trace[4].state == models.BUILD_STATES["ready"]
         assert len(module_build.module_builds_trace) == 5
 
+    @patch("module_build_service.builder.KojiModuleBuilder.KojiModuleBuilder.get_session")
+    @patch("module_build_service.auth.get_user", return_value=user)
+    @patch("module_build_service.scm.SCM")
+    def test_submit_build_buildonly(
+        self, mocked_scm, mocked_get_user, mocked_get_session, conf_system, dbg, hmsc, db_session
+    ):
+        def list_build_rpms(nvr):
+            assert nvr == "perl-List-Compare-1-1"
+            return [{"name": "perl-List-Compare"}]
+        koji_session = MagicMock()
+        koji_session.listBuildRPMs = list_build_rpms
+        mocked_get_session.return_value = koji_session
+
+        yaml_file = "testmodule_v2_buildonly.yaml"
+        FakeSCM(mocked_scm, "testmodule", yaml_file, "620ec77321b2ea7b0d67d82992dda3e1d67055b4")
+
+        rv = self.client.post(
+            "/module-build-service/1/module-builds/",
+            data=json.dumps({
+                "branch": "master",
+                "scmurl": "https://src.stg.fedoraproject.org/modules/"
+                "testmodule.git?#620ec77321b2ea7b0d67d82992dda3e1d67055b4",
+            }),
+        )
+
+        data = json.loads(rv.data)
+        module_build_id = data["id"]
+
+        # Check that components are tagged after the batch is built.
+        tag_groups = [
+            {"perl-Tangerine-1-1", "perl-List-Compare-1-1"},
+            {"tangerine-1-1"},
+        ]
+
+        def on_finalize_cb(cls, succeeded):
+            assert succeeded is True
+
+        def on_tag_artifacts_cb(cls, artifacts, dest_tag=True):
+            assert tag_groups.pop(0) == set(artifacts)
+
+        FakeModuleBuilder.on_finalize_cb = on_finalize_cb
+        FakeModuleBuilder.on_tag_artifacts_cb = on_tag_artifacts_cb
+
+        # Check that the components are added to buildroot after the batch
+        # is built.
+        buildroot_groups = [
+            {"module-build-macros-1-1"},
+            {"perl-Tangerine-1-1", "perl-List-Compare-1-1"},
+            {"tangerine-1-1"},
+        ]
+
+        def on_buildroot_add_artifacts_cb(cls, artifacts, install):
+            assert buildroot_groups.pop(0) == set(artifacts)
+
+        FakeModuleBuilder.on_buildroot_add_artifacts_cb = on_buildroot_add_artifacts_cb
+
+        self.run_scheduler(db_session)
+
+        # All components should be built and module itself should be in "done"
+        # or "ready" state.
+        for build in db_session.query(models.ComponentBuild).filter_by(
+                module_id=module_build_id).all():
+            assert build.state == koji.BUILD_STATES["COMPLETE"]
+            assert build.module_build.state in [
+                models.BUILD_STATES["done"],
+                models.BUILD_STATES["ready"],
+            ]
+
     @pytest.mark.parametrize("gating_result", (True, False))
     @patch("module_build_service.auth.get_user", return_value=user)
     @patch("module_build_service.scm.SCM")
@@ -1010,11 +1058,11 @@ class TestBuild(BaseTestBuild):
         # Check that components are tagged after the batch is built.
         tag_groups = []
         tag_groups.append(
-            set([
+            {
                 "perl-Tangerine-0.23-1.module+0+d027b723",
                 "perl-List-Compare-0.53-5.module+0+d027b723",
                 "tangerine-0.22-3.module+0+d027b723",
-            ])
+            }
         )
 
         def on_tag_artifacts_cb(cls, artifacts, dest_tag=True):
@@ -1024,11 +1072,11 @@ class TestBuild(BaseTestBuild):
         FakeModuleBuilder.on_tag_artifacts_cb = on_tag_artifacts_cb
 
         buildtag_groups = []
-        buildtag_groups.append(set([
+        buildtag_groups.append({
             "perl-Tangerine-0.23-1.module+0+d027b723",
             "perl-List-Compare-0.53-5.module+0+d027b723",
             "tangerine-0.22-3.module+0+d027b723",
-        ]))
+        })
 
         def on_buildroot_add_artifacts_cb(cls, artifacts, install):
             assert buildtag_groups.pop(0) == set(artifacts)
@@ -1089,11 +1137,11 @@ class TestBuild(BaseTestBuild):
         # Check that components are tagged after the batch is built.
         tag_groups = []
         tag_groups.append(
-            set([
+            {
                 "perl-Tangerine-0.23-1.module+0+d027b723",
                 "perl-List-Compare-0.53-5.module+0+d027b723",
                 "tangerine-0.22-3.module+0+d027b723",
-            ])
+            }
         )
 
         def on_tag_artifacts_cb(cls, artifacts, dest_tag=True):
@@ -1103,11 +1151,11 @@ class TestBuild(BaseTestBuild):
         FakeModuleBuilder.on_tag_artifacts_cb = on_tag_artifacts_cb
 
         buildtag_groups = []
-        buildtag_groups.append(set([
+        buildtag_groups.append({
             "perl-Tangerine-0.23-1.module+0+d027b723",
             "perl-List-Compare-0.53-5.module+0+d027b723",
             "tangerine-0.22-3.module+0+d027b723",
-        ]))
+        })
 
         def on_buildroot_add_artifacts_cb(cls, artifacts, install):
             assert buildtag_groups.pop(0) == set(artifacts)
@@ -1728,7 +1776,7 @@ class TestBuild(BaseTestBuild):
 
         def on_buildroot_add_repos_cb(cls, dependencies):
             # Make sure that the metadata module is not present since it doesn't have a Koji tag
-            assert set(dependencies.keys()) == set(["module-f28-build"])
+            assert set(dependencies.keys()) == {"module-f28-build"}
 
         FakeModuleBuilder.on_buildroot_add_repos_cb = on_buildroot_add_repos_cb
         self.run_scheduler(db_session)
@@ -1794,7 +1842,7 @@ class TestLocalBuild(BaseTestBuild):
 
         # Local base-runtime has changed profiles, so we can detect we use
         # the local one and not the main one.
-        FakeModuleBuilder.DEFAULT_GROUPS = {"srpm-build": set(["bar"]), "build": set(["foo"])}
+        FakeModuleBuilder.DEFAULT_GROUPS = {"srpm-build": {"bar"}, "build": {"foo"}}
 
         self.run_scheduler(db_session)
 
