@@ -1,40 +1,22 @@
-# Copyright (c) 2019 Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 from collections import namedtuple
 import errno
-import textwrap
 
 import dnf
-from mock import call, Mock, patch
+from mock import call, Mock, patch, PropertyMock
 import pytest
-import requests
 
+from module_build_service.errors import UnprocessableEntity
 from module_build_service.models import ModuleBuild
 from module_build_service.scheduler import default_modules
 from module_build_service.utils.general import load_mmd, mmd_to_str
-from tests import clean_database, make_module_in_db, read_staged_data
+from tests import clean_database, conf, make_module_in_db, read_staged_data
 
 
-@patch("module_build_service.scheduler.default_modules._handle_collisions")
-@patch("module_build_service.scheduler.default_modules.requests_session")
-def test_add_default_modules(mock_requests_session, mock_hc, db_session):
+@patch("module_build_service.scheduler.default_modules.handle_collisions_with_base_module_rpms")
+@patch("module_build_service.scheduler.default_modules._get_default_modules")
+def test_add_default_modules(mock_get_dm, mock_hc, db_session):
     """
     Test that default modules present in the database are added, and the others are ignored.
     """
@@ -55,30 +37,30 @@ def test_add_default_modules(mock_requests_session, mock_hc, db_session):
     assert platform
     platform_mmd = platform.mmd()
     platform_xmd = mmd.get_xmd()
-    default_modules_url = "http://domain.local/default_modules.txt"
-    platform_xmd["mbs"]["default_modules_url"] = default_modules_url
+    platform_xmd["mbs"]["use_default_modules"] = True
     platform_mmd.set_xmd(platform_xmd)
     platform.modulemd = mmd_to_str(platform_mmd)
     db_session.commit()
 
-    mock_requests_session.get.return_value.ok = True
-    # Also ensure that if there's an invalid line, it's just ignored
-    mock_requests_session.get.return_value.text = textwrap.dedent("""\
-        nodejs:11
-        python:3
-        ruby:2.6
-        some invalid stuff
-    """)
-    default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+    mock_get_dm.return_value = {
+        "nodejs": "11",
+        "python": "3",
+        "ruby": "2.6",
+    }
+    defaults_added = default_modules.add_default_modules(db_session, mmd, ["x86_64"])
     # Make sure that the default modules were added. ruby:2.6 will be ignored since it's not in
     # the database
     assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"nodejs", "platform", "python"}
-    mock_requests_session.get.assert_called_once_with(default_modules_url, timeout=10)
-    mock_hc.assert_called_once()
+    mock_get_dm.assert_called_once_with(
+        "f28",
+        "https://pagure.io/releng/fedora-module-defaults.git",
+    )
+    assert "ursine_rpms" not in mmd.get_xmd()["mbs"]
+    assert defaults_added is True
 
 
-@patch("module_build_service.scheduler.default_modules.requests_session")
-def test_add_default_modules_not_linked(mock_requests_session, db_session):
+@patch("module_build_service.scheduler.default_modules._get_default_modules")
+def test_add_default_modules_not_linked(mock_get_dm, db_session):
     """
     Test that no default modules are added when they aren't linked from the base module.
     """
@@ -87,11 +69,10 @@ def test_add_default_modules_not_linked(mock_requests_session, db_session):
     assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"platform"}
     default_modules.add_default_modules(db_session, mmd, ["x86_64"])
     assert set(mmd.get_xmd()["mbs"]["buildrequires"].keys()) == {"platform"}
-    mock_requests_session.get.assert_not_called()
+    mock_get_dm.assert_not_called()
 
 
-@patch("module_build_service.scheduler.default_modules.requests_session")
-def test_add_default_modules_platform_not_available(mock_requests_session, db_session):
+def test_add_default_modules_platform_not_available(db_session):
     """
     Test that an exception is raised when the platform module that is buildrequired is missing.
 
@@ -105,11 +86,10 @@ def test_add_default_modules_platform_not_available(mock_requests_session, db_se
         default_modules.add_default_modules(db_session, mmd, ["x86_64"])
 
 
-@pytest.mark.parametrize("connection_error", (True, False))
-@patch("module_build_service.scheduler.default_modules.requests_session")
-def test_add_default_modules_request_failed(mock_requests_session, connection_error, db_session):
+@patch("module_build_service.scheduler.default_modules._get_default_modules")
+def test_add_default_modules_request_failed(mock_get_dm, db_session):
     """
-    Test that an exception is raised when the request to get the default modules failed.
+    Test that an exception is raised when the call to _get_default_modules failed.
     """
     clean_database()
     make_module_in_db("python:3:12345:1", db_session=db_session)
@@ -128,32 +108,109 @@ def test_add_default_modules_request_failed(mock_requests_session, connection_er
     assert platform
     platform_mmd = platform.mmd()
     platform_xmd = mmd.get_xmd()
-    default_modules_url = "http://domain.local/default_modules.txt"
-    platform_xmd["mbs"]["default_modules_url"] = default_modules_url
+    platform_xmd["mbs"]["use_default_modules"] = True
     platform_mmd.set_xmd(platform_xmd)
     platform.modulemd = mmd_to_str(platform_mmd)
     db_session.commit()
 
-    if connection_error:
-        mock_requests_session.get.side_effect = requests.ConnectionError("some error")
-        expected_error = (
-            "The connection failed when getting the default modules associated with "
-            "platform:f28:3:00000000"
+    expected_error = "some error"
+    mock_get_dm.side_effect = ValueError(expected_error)
+
+    with pytest.raises(ValueError, match=expected_error):
+        default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+
+
+@pytest.mark.parametrize("is_rawhide", (True, False))
+@patch("shutil.rmtree")
+@patch("tempfile.mkdtemp")
+@patch("module_build_service.scheduler.default_modules.Modulemd.ModuleIndex.new")
+@patch("module_build_service.scheduler.default_modules.scm.SCM")
+@patch("module_build_service.scheduler.default_modules._get_rawhide_version")
+def test_get_default_modules(
+    mock_get_rawhide, mock_scm, mock_mmd_new, mock_mkdtemp, mock_rmtree, is_rawhide,
+):
+    """
+    Test that _get_default_modules returns the default modules.
+    """
+    mock_scm.return_value.sourcedir = "/some/path"
+    if is_rawhide:
+        mock_scm.return_value.checkout_ref.side_effect = [
+            UnprocessableEntity("invalid branch"),
+            None,
+        ]
+        mock_get_rawhide.return_value = "f32"
+
+    expected = {"nodejs": "11"}
+    mock_mmd_new.return_value.get_default_streams.return_value = expected
+
+    rv = default_modules._get_default_modules("f32", conf.default_modules_scm_url)
+
+    assert rv == expected
+    if is_rawhide:
+        mock_scm.return_value.checkout_ref.assert_has_calls(
+            [call("f32"), call(conf.rawhide_branch)]
         )
     else:
-        mock_requests_session.get.return_value.ok = False
-        mock_requests_session.get.return_value.text = "some error"
-        expected_error = "Failed to retrieve the default modules for platform:f28:3:00000000"
+        mock_scm.return_value.checkout_ref.assert_called_once_with("f32")
 
-    with pytest.raises(RuntimeError, match=expected_error):
-        default_modules.add_default_modules(db_session, mmd, ["x86_64"])
+
+@pytest.mark.parametrize("uses_rawhide", (True, False))
+@patch("shutil.rmtree")
+@patch("tempfile.mkdtemp")
+@patch(
+    "module_build_service.scheduler.default_modules.conf.uses_rawhide",
+    new_callable=PropertyMock,
+)
+@patch("module_build_service.scheduler.default_modules.Modulemd.ModuleIndex.new")
+@patch("module_build_service.scheduler.default_modules.scm.SCM")
+@patch("module_build_service.scheduler.default_modules._get_rawhide_version")
+def test_get_default_modules_invalid_branch(
+    mock_get_rawhide, mock_scm, mock_mmd_new, mock_uses_rawhide, mock_mkdtemp, mock_rmtree,
+    uses_rawhide,
+):
+    """
+    Test that _get_default_modules raises an exception with an invalid branch.
+    """
+    mock_uses_rawhide.return_value = uses_rawhide
+    mock_scm.return_value.sourcedir = "/some/path"
+    mock_scm.return_value.checkout_ref.side_effect = [
+        UnprocessableEntity("invalid branch"),
+        UnprocessableEntity("invalid branch"),
+    ]
+    if uses_rawhide:
+        mock_get_rawhide.return_value = "f32"
+    else:
+        mock_get_rawhide.return_value = "something_else"
+
+    with pytest.raises(ValueError, match="Failed to retrieve the default modules"):
+        default_modules._get_default_modules("f32", conf.default_modules_scm_url)
+
+    mock_mmd_new.assert_not_called()
+    if uses_rawhide:
+        mock_scm.return_value.checkout_ref.assert_has_calls(
+            [call("f32"), call(conf.rawhide_branch)],
+        )
+    else:
+        mock_scm.return_value.checkout_ref.assert_called_once_with("f32")
+
+
+@patch("module_build_service.scheduler.default_modules.KojiModuleBuilder")
+def test_get_rawhide_version(mock_koji_builder):
+    """
+    Test that _get_rawhide_version will return rawhide Fedora version.
+    """
+    mock_koji_builder.get_session.return_value.getBuildTarget.return_value = {
+        "build_tag_name": "f32-build",
+    }
+    assert default_modules._get_rawhide_version() == "f32"
 
 
 @patch("module_build_service.scheduler.default_modules.KojiModuleBuilder.get_session")
 @patch("module_build_service.scheduler.default_modules._get_rpms_from_tags")
-def test_handle_collisions(mock_grft, mock_get_session):
+def test_handle_collisions_with_base_module_rpms(mock_grft, mock_get_session):
     """
-    Test that _handle_collisions will add conflicts for NEVRAs in the modulemd.
+    Test that handle_collisions_with_base_module_rpms will add conflicts for NEVRAs in the
+    modulemd.
     """
     mmd = load_mmd(read_staged_data("formatted_testmodule.yaml"))
     xmd = mmd.get_xmd()
@@ -177,27 +234,27 @@ def test_handle_collisions(mock_grft, mock_get_session):
     }
     mock_grft.side_effect = [bm_rpms, non_bm_rpms]
 
-    default_modules._handle_collisions(mmd, ["aarch64", "x86_64"])
+    default_modules.handle_collisions_with_base_module_rpms(mmd, ["aarch64", "x86_64"])
 
     mock_get_session.assert_called_once()
     xmd_mbs = mmd.get_xmd()["mbs"]
-    assert set(xmd_mbs["ursine_rpms"]) == set([
+    assert set(xmd_mbs["ursine_rpms"]) == {
         "bash-0:4.4.19-7.el8.aarch64",
         "python2-tools-0:2.7.16-11.el8.aarch64",
         "python2-tools-0:2.7.16-11.el8.x86_64",
-    ])
-    mock_grft.mock_calls == [
-        call(
-            mock_get_session.return_value,
-            {"module-el-build"},
-            ["aarch64", "x86_64"],
-        ),
-        call(
-            mock_get_session.return_value,
-            {"module-bash", "module-python27"},
-            ["aarch64", "x86_64"],
-        ),
-    ]
+    }
+    assert mock_grft.call_count == 2
+    # We can't check the calls directly because the second argument is a set converted to a list,
+    # so the order can't be determined ahead of time.
+    first_call = mock_grft.mock_calls[0][1]
+    assert first_call[0] == mock_get_session.return_value
+    assert first_call[1] == ["module-el-build"]
+    assert first_call[2] == ["aarch64", "x86_64"]
+
+    second_call = mock_grft.mock_calls[1][1]
+    assert second_call[0] == mock_get_session.return_value
+    assert set(second_call[1]) == {"module-bash", "module-python27"}
+    assert second_call[2] == ["aarch64", "x86_64"]
 
 
 @patch("module_build_service.scheduler.default_modules.koji_retrying_multicall_map")
@@ -324,10 +381,12 @@ def test_get_rpms_in_external_repo(mock_makedirs, mock_dnf_base):
         RPM("aarch64", 0, "python", "1.el8", "3.7"),
         RPM("x86_64", 0, "python", "1.el8", "2.7"),
         RPM("x86_64", 0, "python", "1.el8", "3.7"),
+        RPM("i686", 0, "python", "1.el8", "2.7"),
+        RPM("i686", 0, "python", "1.el8", "3.7"),
     ]
 
     external_repo_url = "http://domain.local/repo/latest/$arch/"
-    arches = ["aarch64", "x86_64"]
+    arches = ["aarch64", "x86_64", "i686"]
     cache_dir_name = "module-el-build-12"
     rv = default_modules._get_rpms_in_external_repo(external_repo_url, arches, cache_dir_name)
 
@@ -336,9 +395,19 @@ def test_get_rpms_in_external_repo(mock_makedirs, mock_dnf_base):
         "python-0:3.7-1.el8.aarch64",
         "python-0:2.7-1.el8.x86_64",
         "python-0:3.7-1.el8.x86_64",
+        "python-0:2.7-1.el8.i686",
+        "python-0:3.7-1.el8.i686",
     }
     assert rv == expected
 
+    # Test that i686 is mapped to i386 using the koji.canonArch().
+    mock_dnf_base.return_value.repos.add_new_repo.assert_called_with(
+        "repo_i386",
+        mock_dnf_base.return_value.conf,
+        baseurl=["http://domain.local/repo/latest/i386/"],
+        minrate=conf.dnf_minrate,
+    )
+
 
 def test_get_rpms_in_external_repo_invalid_repo_url():
     """
@@ -365,14 +434,11 @@ def test_get_rpms_in_external_repo_failed_to_load(mock_makedirs, mock_dnf_base):
         def add_new_repo(*args, **kwargs):
             pass
 
-    mock_repo = Mock()
-    mock_repo.load.side_effect = dnf.exceptions.RepoError("Failed")
-    mock_dnf_base.return_value.repos = FakeRepo(repo_aarch64=mock_repo)
-
+    mock_dnf_base.return_value.update_cache.side_effect = dnf.exceptions.RepoError("Failed")
     external_repo_url = "http://domain.local/repo/latest/$arch/"
     arches = ["aarch64", "x86_64"]
     cache_dir_name = "module-el-build-12"
-    expected = "Failed to load the external repo http://domain.local/repo/latest/aarch64/"
+    expected = "Failed to load the external repos"
     with pytest.raises(RuntimeError, match=expected):
         default_modules._get_rpms_in_external_repo(external_repo_url, arches, cache_dir_name)
 
