@@ -1,24 +1,5 @@
-# Copyright (c) 2017 Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 import os
 
 from mock import patch, PropertyMock
@@ -59,8 +40,11 @@ class TestModuleInit:
     )
     @patch("module_build_service.scm.SCM")
     @patch("module_build_service.scheduler.handlers.modules.handle_stream_collision_modules")
+    @patch(
+        "module_build_service.scheduler.handlers.modules.handle_collisions_with_base_module_rpms"
+    )
     @patch("module_build_service.utils.submit.get_build_arches", return_value=["x86_64"])
-    def init_basic(self, db_session, get_build_arches, rscm, mocked_scm, built_rpms):
+    def init_basic(self, db_session, get_build_arches, hcwbmr, rscm, mocked_scm, built_rpms):
         FakeSCM(
             mocked_scm,
             "testmodule",
@@ -102,6 +86,7 @@ class TestModuleInit:
             "foo-0:2.4.48-3.el8+1308+551bfa71",
             "bar-0:2.5.48-3.el8+1308+551bfa71",
         ]
+        hcwbmr.assert_called_once()
         return build
 
     def test_init_called_twice(self, db_session):
