@@ -1,28 +1,10 @@
-# Copyright (c) 2017  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 import re
 import pytest
 from mock import patch
 from module_build_service import models, conf
-from tests import clean_database
+from tests import clean_database, make_module_in_db
 import mock
 import koji
 from module_build_service.scheduler.producer import MBSProducer
@@ -710,8 +692,12 @@ class TestPoller:
         module_build2 = models.ModuleBuild.get_by_id(db_session, 2)
         module_build2.state = models.BUILD_STATES["done"]
 
-        module_build2 = models.ModuleBuild.get_by_id(db_session, 3)
-        module_build2.state = models.BUILD_STATES["init"]
+        module_build3 = models.ModuleBuild.get_by_id(db_session, 3)
+        module_build3.state = models.BUILD_STATES["init"]
+
+        module_build4 = make_module_in_db("foo:1:1:1", {}, db_session=db_session)
+        module_build4.state = models.BUILD_STATES["done"]
+        module_build4.scratch = True
 
         db_session.commit()
 
@@ -732,11 +718,15 @@ class TestPoller:
 
         if greenwave_result:
             assert len(modules) == 2
-            assert set([m.id for m in modules]) == {1, 2}
+            assert {m.id for m in modules} == {1, 2}
         else:
             assert len(modules) == 1
             assert modules[0].id == 1
             modules = models.ModuleBuild.by_state(db_session, "done")
-            assert len(modules) == 1
-            assert modules[0].id == 2
-            assert re.match("Gating failed.*", modules[0].state_reason)
+            assert len(modules) == 2
+            for module in modules:
+                assert module.id in [2, 4]
+                if module.id == 2:
+                    assert re.match("Gating failed.*", module.state_reason)
+                else:
+                    assert module.state_reason is None
