@@ -1,23 +1,5 @@
-# Copyright (c) 2017  Red Hat, Inc.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-
+# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: MIT
 import io
 import tempfile
 import hashlib
@@ -26,6 +8,7 @@ from shutil import copyfile, rmtree
 from datetime import datetime
 from werkzeug.datastructures import FileStorage
 from mock import patch
+from sqlalchemy.orm.session import make_transient
 from module_build_service.utils.general import load_mmd_file, mmd_to_str
 import module_build_service.utils
 import module_build_service.scm
@@ -38,6 +21,7 @@ from tests import (
     init_data,
     scheduler_init_data,
     make_module_in_db,
+    make_module,
     read_staged_data, staged_data_filename)
 import mock
 import koji
@@ -576,7 +560,7 @@ class TestUtils:
         build.arches = []
         module_build_service.utils.record_module_build_arches(build.mmd(), build, db_session)
 
-        arches = set([arch.name for arch in build.arches])
+        arches = {arch.name for arch in build.arches}
         assert arches == set(get_build_arches.return_value)
 
     @pytest.mark.parametrize(
@@ -1051,6 +1035,31 @@ class TestUtils:
         assert builds[0].siblings(db_session) == [builds[1].id]
         assert builds[1].siblings(db_session) == [builds[0].id]
 
+    @patch("module_build_service.utils.mse.generate_expanded_mmds")
+    @patch(
+        "module_build_service.config.Config.scratch_build_only_branches",
+        new_callable=mock.PropertyMock,
+        return_value=["^private-.*"],
+    )
+    def test_submit_build_scratch_build_only_branches(
+            self, cfg, generate_expanded_mmds, db_session):
+        """
+        Tests the "scratch_build_only_branches" config option.
+        """
+        mmd = make_module("foo:stream:0:c1")
+        generate_expanded_mmds.return_value = [mmd]
+        # Create a copy of mmd1 without xmd.mbs, since that will cause validate_mmd to fail
+        mmd_copy = mmd.copy()
+        mmd_copy.set_xmd({})
+
+        with pytest.raises(ValidationError,
+                           match="Only scratch module builds can be built from this branch."):
+            module_build_service.utils.submit_module_build(
+                db_session, "foo", mmd_copy, {"branch": "private-foo"})
+
+        module_build_service.utils.submit_module_build(
+            db_session, "foo", mmd_copy, {"branch": "otherbranch"})
+
 
 class DummyModuleBuilder(GenericBuilder):
     """
@@ -1511,7 +1520,7 @@ class TestOfflineLocalBuilds:
             }
         }
 
-        assert set(mmd.get_profile_names()) == set(["buildroot", "srpm-buildroot"])
+        assert set(mmd.get_profile_names()) == {"buildroot", "srpm-buildroot"}
 
     @patch("module_build_service.utils.general.open", create=True, new_callable=mock.mock_open)
     def test_import_builds_from_local_dnf_repos(self, patched_open, db_session):
@@ -1588,3 +1597,151 @@ class TestUtilsModuleReuse:
         assert build_module.reused_module
         assert reusable_module.id == build_module.reused_module_id
         assert reusable_module.id == reused_module.id
+
+    @pytest.mark.parametrize("allow_ocbm", (True, False))
+    @patch(
+        "module_build_service.config.Config.allow_only_compatible_base_modules",
+        new_callable=mock.PropertyMock,
+    )
+    def test_get_reusable_module_use_latest_build(self, cfg, db_session, allow_ocbm):
+        """
+        Test that the `get_reusable_module` tries to reuse the latest module in case when
+        multiple modules can be reused allow_only_compatible_base_modules is True.
+        """
+        cfg.return_value = allow_ocbm
+        # Set "fedora" virtual stream to platform:f28.
+        platform_f28 = db_session.query(models.ModuleBuild).filter_by(name="platform").one()
+        mmd = platform_f28.mmd()
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["virtual_streams"] = ["fedora"]
+        mmd.set_xmd(xmd)
+        platform_f28.modulemd = mmd_to_str(mmd)
+        platform_f28.update_virtual_streams(db_session, ["fedora"])
+
+        # Create platform:f29 with "fedora" virtual stream.
+        mmd = load_mmd(read_staged_data("platform"))
+        mmd = mmd.copy("platform", "f29")
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["virtual_streams"] = ["fedora"]
+        mmd.set_xmd(xmd)
+        platform_f29 = module_build_service.utils.import_mmd(db_session, mmd)[0]
+
+        # Create another copy of `testmodule:master` which should be reused, because its
+        # stream version will be higher than the previous one. Also set its buildrequires
+        # to platform:f29.
+        latest_module = db_session.query(models.ModuleBuild).filter_by(
+            name="testmodule", state=models.BUILD_STATES["ready"]).one()
+        # This is used to clone the ModuleBuild SQLAlchemy object without recreating it from
+        # scratch.
+        db_session.expunge(latest_module)
+        make_transient(latest_module)
+
+        # Change the platform:f28 buildrequirement to platform:f29 and recompute the build_context.
+        mmd = latest_module.mmd()
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["buildrequires"]["platform"]["stream"] = "f29"
+        mmd.set_xmd(xmd)
+        latest_module.modulemd = mmd_to_str(mmd)
+        latest_module.build_context = module_build_service.models.ModuleBuild.contexts_from_mmd(
+            latest_module.modulemd
+        ).build_context
+        latest_module.buildrequires = [platform_f29]
+
+        # Set the `id` to None, so new one is generated by SQLAlchemy.
+        latest_module.id = None
+        db_session.add(latest_module)
+        db_session.commit()
+
+        module = db_session.query(models.ModuleBuild)\
+                           .filter_by(name="testmodule")\
+                           .filter_by(state=models.BUILD_STATES["build"])\
+                           .one()
+        db_session.commit()
+
+        reusable_module = module_build_service.utils.get_reusable_module(
+            db_session, module)
+
+        if allow_ocbm:
+            assert reusable_module.id == latest_module.id
+        else:
+            first_module = db_session.query(models.ModuleBuild).filter_by(
+                name="testmodule", state=models.BUILD_STATES["ready"]).first()
+            assert reusable_module.id == first_module.id
+
+    @pytest.mark.parametrize("allow_ocbm", (True, False))
+    @patch(
+        "module_build_service.config.Config.allow_only_compatible_base_modules",
+        new_callable=mock.PropertyMock,
+    )
+    @patch("module_build_service.builder.KojiModuleBuilder.KojiClientSession")
+    @patch(
+        "module_build_service.config.Config.resolver",
+        new_callable=mock.PropertyMock, return_value="koji"
+    )
+    def test_get_reusable_module_koji_resolver(
+            self, resolver, ClientSession, cfg, db_session, allow_ocbm):
+        """
+        Test that get_reusable_module works with KojiResolver.
+        """
+        cfg.return_value = allow_ocbm
+
+        # Mock the listTagged so the testmodule:master is listed as tagged in the
+        # module-fedora-27-build Koji tag.
+        koji_session = ClientSession.return_value
+        koji_session.listTagged.return_value = [
+            {
+                "build_id": 123, "name": "testmodule", "version": "master",
+                "release": "20170109091357.78e4a6fd", "tag_name": "module-fedora-27-build"
+            }]
+
+        # Mark platform:f28 as KojiResolver ready by defining "koji_tag_with_modules".
+        # Also define the "virtual_streams" to possibly confuse the get_reusable_module.
+        platform_f28 = db_session.query(models.ModuleBuild).filter_by(name="platform").one()
+        mmd = platform_f28.mmd()
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["virtual_streams"] = ["fedora"]
+        xmd["mbs"]["koji_tag_with_modules"] = "module-fedora-27-build"
+        mmd.set_xmd(xmd)
+        platform_f28.modulemd = mmd_to_str(mmd)
+        platform_f28.update_virtual_streams(db_session, ["fedora"])
+
+        # Create platform:f27 without KojiResolver support.
+        mmd = load_mmd(read_staged_data("platform"))
+        mmd = mmd.copy("platform", "f27")
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["virtual_streams"] = ["fedora"]
+        mmd.set_xmd(xmd)
+        platform_f27 = module_build_service.utils.import_mmd(db_session, mmd)[0]
+
+        # Change the reusable testmodule:master to buildrequire platform:f27.
+        latest_module = db_session.query(models.ModuleBuild).filter_by(
+            name="testmodule", state=models.BUILD_STATES["ready"]).one()
+        mmd = latest_module.mmd()
+        xmd = mmd.get_xmd()
+        xmd["mbs"]["buildrequires"]["platform"]["stream"] = "f27"
+        mmd.set_xmd(xmd)
+        latest_module.modulemd = mmd_to_str(mmd)
+        latest_module.buildrequires = [platform_f27]
+
+        # Recompute the build_context and ensure that `build_context` changed while
+        # `build_context_no_bms` did not change.
+        contexts = module_build_service.models.ModuleBuild.contexts_from_mmd(
+            latest_module.modulemd)
+
+        assert latest_module.build_context_no_bms == contexts.build_context_no_bms
+        assert latest_module.build_context != contexts.build_context
+
+        latest_module.build_context = contexts.build_context
+        latest_module.build_context_no_bms = contexts.build_context_no_bms
+        db_session.commit()
+
+        # Get the module we want to build.
+        module = db_session.query(models.ModuleBuild)\
+                           .filter_by(name="testmodule")\
+                           .filter_by(state=models.BUILD_STATES["build"])\
+                           .one()
+
+        reusable_module = module_build_service.utils.get_reusable_module(
+            db_session, module)
+
+        assert reusable_module.id == latest_module.id
